pub fn generate_csharp_object(info: &DlrlTypeInfo) -> StringExpand description
Additionally generates a separate object class (complete, not
partial) — for callers that do not need the type as a user anchor.
pub fn generate_csharp_object(info: &DlrlTypeInfo) -> StringAdditionally generates a separate object class (complete, not
partial) — for callers that do not need the type as a user anchor.